@@ -62,7 +62,7 @@ base_breaks <- function(n = 10) {
 }
 
 
-#' @importFrom sjmisc get_label get_labels str_contains to_label to_value replace_na word_wrap
+#' @importFrom sjmisc str_contains to_label to_value replace_na word_wrap
 #' @importFrom sjstats resp_val resp_var
 get_lm_data <- function(fit) {
   if (inherits(fit, "plm")) {
@@ -93,7 +93,7 @@ get_lm_data <- function(fit) {
     depvar.label <- sjstats::resp_var(fit)
   }
   # get variable label label
-  depvar.label <- unname(sjmisc::get_label(x = resp, def.value = depvar.label))
+  depvar.label <- unname(sjlabelled::get_label(x = resp, def.value = depvar.label))
   return(list(matrix = fit_x, resp.label = depvar.label, resp = resp))
 }
 
@@ -196,6 +196,7 @@ get_var_name <- function(x) {
 #' @importFrom stats na.omit
 #' @importFrom dplyr full_join
 #' @importFrom sjmisc zap_inf
+#' @importFrom sjlabelled get_label get_labels
 create.frq.df <- function(x,
                           wrap.labels = Inf,
                           order.frq = "none",
@@ -223,7 +224,7 @@ create.frq.df <- function(x,
   #---------------------------------------------------
   # get value labels (if any)
   #---------------------------------------------------
-  labels <- sjmisc::get_labels(
+  labels <- sjlabelled::get_labels(
     x,
     attr.only = T,
     include.values = "n",
@@ -362,65 +363,65 @@ create.xtab.df <- function(x,
                                                 exclude = NULL,
                                                 na.action = stats::na.pass)), 0)
   }
-  
+
   # create proportional tables, cell values
   ori.cell.values <- 100 * prop.table(mydat)
   proptab.cell <- round(100 * prop.table(mydat), round.prz)
-  
+
   # create proportional tables, row percentages, including total row
   proptab.row <- rbind(
     as.data.frame(as.matrix(round(100 * prop.table(mydat, 1), round.prz))),
     round(colSums(ori.cell.values), round.prz)
   )
-  
+
   rownames(proptab.row)[nrow(proptab.row)] <- "total"
   proptab.row <- as.data.frame(apply(proptab.row, c(1, 2), function(x) if (is.na(x)) x <- 0 else x))
-  
+
   # create proportional tables, column  percentages, including total row
   proptab.col <- cbind(
     as.data.frame(as.matrix(round(100 * prop.table(mydat, 2), round.prz))),
     round(rowSums(ori.cell.values), round.prz)
   )
-  
+
   colnames(proptab.col)[ncol(proptab.col)] <- "total"
   proptab.col <- as.data.frame(apply(proptab.col, c(1, 2), function(x) if (is.na(x)) x <- 0 else x))
-  
+
   # add total row and column to cell percentages afterwards
   proptab.cell <- rbind(
-    as.data.frame(as.matrix(proptab.cell)), 
+    as.data.frame(as.matrix(proptab.cell)),
     round(colSums(ori.cell.values), round.prz)
   )
-  
+
   proptab.cell <- cbind(
     as.data.frame(as.matrix(proptab.cell)),
     rowSums(proptab.cell)
   )
-  
+
   # due to roundings, total might differ from 100%, so clean this here
   proptab.cell[nrow(proptab.cell), ncol(proptab.cell)] <- 100
   colnames(proptab.cell)[ncol(proptab.cell)] <- "total"
   rownames(proptab.cell)[nrow(proptab.cell)] <- "total"
-  
+
   # convert to data frame
   mydat <- data.frame(mydat)
   colnames(mydat)[2] <- "Var2"
-  
+
   # spread variables back, so we have a table again
   mydat <- tidyr::spread(mydat, Var2, Freq)
-  
+
   # rename column names
   colnames(mydat)[1] <- "label"
   colnames(mydat)[is.na(colnames(mydat))] <- "NA"
   colnames(mydat)[colnames(mydat) == "<NA>"] <- "NA"
-  
+
   # label must be character
   mydat$label <- as.character(mydat$label)
   mydat$label[is.na(mydat$label)] <- "NA"
-  
+
   # save labels to extra vector
   labels.cnt <- mydat$label
   labels.grp <- colnames(mydat)[-1]
-  
+
   # return result
   invisible(structure(list(mydat = mydat,
                            proptab.cell = proptab.cell,
@@ -437,11 +438,11 @@ get.encoding <- function(encoding, data = NULL) {
   if (is.null(encoding)) {
     if (!is.null(data) && is.data.frame(data)) {
       # get variable label
-      labs <- sjmisc::get_label(data[[1]])
+      labs <- sjlabelled::get_label(data[[1]])
       # check if vectors of data frame have
       # any valid label. else, default to utf-8
       if (!is.null(labs) && is.character(labs))
-        encoding <- Encoding(sjmisc::get_label(data[[1]]))
+        encoding <- Encoding(sjlabelled::get_label(data[[1]]))
       else
         encoding <- "UTF-8"
       # unknown encoding? default to utf-8
@@ -510,7 +511,7 @@ crosstabsum <- function(x, grp, weight.by) {
     # check whether fisher's test or chi-squared should be printed
     if (is.null(fish)) {
       modsum <- as.character(as.expression(
-        substitute("N" == tn * "," ~~ chi^2 == c2 * "," ~~ "df" == dft * "," ~~ phi[c] == kook * "," ~~ "p" < pva,
+        substitute("N" == tn * "," ~~ chi^2 == c2 * "," ~~ "df" == dft * "," ~~ phi[c] == kook * "," ~~ "p" == pva,
                    list(tn = summary(ftab)$n.cases,
                         c2 = sprintf("%.2f", chsq$statistic),
                         dft = c(chsq$parameter),
@@ -518,7 +519,7 @@ crosstabsum <- function(x, grp, weight.by) {
                         pva = pvas))))
     } else {
       modsum <- as.character(as.expression(
-        substitute("N" == tn * "," ~~ "df" == dft * "," ~~ phi[c] == kook * "," ~~ "Fisher's p" < pva,
+        substitute("N" == tn * "," ~~ "df" == dft * "," ~~ phi[c] == kook * "," ~~ "Fisher's p" == pva,
                    list(tn = summary(ftab)$n.cases,
                         dft = c(chsq$parameter),
                         kook = sprintf("%.2f", sjstats::cramer(ftab)),
@@ -586,7 +587,7 @@ retrieveModelGroupIndices <- function(models, rem_rows = NULL) {
           # if not, save found factor variable name
           found.factors <- c(found.factors, fac.name)
           # save factor name
-          lab <- unname(sjmisc::get_label(fit.var, def.value = fac.name))
+          lab <- unname(sjlabelled::get_label(fit.var, def.value = fac.name))
           # determins startindex
           index <- grp.cnt + add.index - 1
           index.add <- nlevels(fit.var) - 2
@@ -682,7 +683,7 @@ retrieveModelLabels <- function(models, group.pred) {
           # get predictor
           pvar <- m_f[, i]
           # check if we have a variable label
-          lab <- sjmisc::get_label(pvar, def.value = colnames(m_f)[i])
+          lab <- sjlabelled::get_label(pvar, def.value = colnames(m_f)[i])
           # get model coefficients' names
           coef_name <- coef_names[i]
           # is predictor a factor?
@@ -692,7 +693,7 @@ retrieveModelLabels <- function(models, group.pred) {
             # get amount of levels
             pvar.len <- nlevels(pvar)
             # get value labels, if any
-            pvar.lab <- sjmisc::get_labels(pvar)
+            pvar.lab <- sjlabelled::get_labels(pvar)
             # have any labels, and have we same amount of labels
             # as factor levels?
             if (!is.null(pvar.lab) && length(pvar.lab) == pvar.len) {
@@ -786,7 +787,7 @@ unlistlabels <- function(lab) {
 
 get_model_response_label <- function(fit) {
   m_f <- stats::model.frame(fit)
-  unname(sjmisc::get_label(m_f[[1]], def.value = colnames(m_f)[1]))
+  unname(sjlabelled::get_label(m_f[[1]], def.value = colnames(m_f)[1]))
 }
 
 
@@ -871,14 +872,11 @@ sju.rmspc <- function(html.table) {
 
 
 get_p_stars <- function(pval) {
-  pan <- ""
-  if (is.na(pval))
-    pan <- ""
-  else if (pval < 0.001)
-    pan <- "***"
-  else if (pval < 0.01)
-    pan <- "**"
-  else if (pval < 0.05)
-    pan <- "*"
-  return(invisible(pan))
+  dplyr::case_when(
+    is.na(pval) ~ "",
+    pval < 0.001 ~ "***",
+    pval < 0.01 ~ "**",
+    pval < 0.05 ~ "*",
+    TRUE ~ ""
+  )
 }
