@@ -250,16 +250,16 @@ sjp.frq <- function(var.cnt,
     # group axis labels
     axis.labels <- sjmisc::group_labels(
       sjmisc::to_value(var.cnt, keep.labels = F),
-      groupsize = "auto",
-      groupcount = auto.group
+      size = "auto",
+      n = auto.group
     )
 
     # group variable
     var.cnt <- sjmisc::group_var(
       sjmisc::to_value(var.cnt, keep.labels = F),
-      groupsize = "auto",
+      size = "auto",
       as.num = TRUE,
-      groupcount = auto.group
+      n = auto.group
     )
 
     # set label attributes
@@ -356,8 +356,8 @@ sjp.frq <- function(var.cnt,
       upper_lim <- max(pretty(table(
         sjmisc::group_var(
           var.cnt,
-          groupsize = "auto",
-          groupcount = hist.grp.cnt
+          size = "auto",
+          n = hist.grp.cnt
         )
       ) * 1.1))
     } else {
